Fvar

Struct Fvar 

pub struct Fvar<'a> {
    data: FontData<'a>,
}
Fields

data: FontData<'a>

Implementations

Source

impl<'a> Fvar<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> MajorMinor

Major version number of the font variations table — set to 1. Minor version number of the font variations table — set to 0.

pub fn axis_instance_arrays_offset(&self) -> Offset16

Offset in bytes from the beginning of the table to the start of the VariationAxisRecord array. The InstanceRecord array directly follows.

pub fn axis_instance_arrays(&self) -> Result<AxisInstanceArrays<'a>, ReadError>

Attempt to resolve axis_instance_arrays_offset.

pub fn axis_count(&self) -> u16

The number of variation axes in the font (the number of records in the axes array).

pub fn axis_size(&self) -> u16

The size in bytes of each VariationAxisRecord — set to 20 (0x0014) for this version.

pub fn instance_count(&self) -> u16

The number of named instances defined in the font (the number of records in the instances array).

pub fn instance_size(&self) -> u16

The size in bytes of each InstanceRecord — set to either axisCount * sizeof(Fixed) + 4, or to axisCount * sizeof(Fixed) + 6.

pub fn version_byte_range(&self) -> Range<usize>

pub fn axis_instance_arrays_offset_byte_range(&self) -> Range<usize>

pub fn _reserved_byte_range(&self) -> Range<usize>

pub fn axis_count_byte_range(&self) -> Range<usize>

pub fn axis_size_byte_range(&self) -> Range<usize>

pub fn instance_count_byte_range(&self) -> Range<usize>

pub fn instance_size_byte_range(&self) -> Range<usize>

Source

impl<'a> Fvar<'a>

pub fn axes(&self) -> Result<&'a [VariationAxisRecord], ReadError>

Returns the array of variation axis records.

pub fn instances( &self, ) -> Result<ComputedArray<'a, InstanceRecord<'a>>, ReadError>

Returns the array of instance records.

pub fn user_to_normalized( &self, avar: Option<&Avar<'_>>, user_coords: impl IntoIterator<Item = (Tag, Fixed)>, normalized_coords: &mut [F2Dot14], )

Converts user space coordinates provided by an unordered iterator of (tag, value) pairs to normalized coordinates in axis list order.

Stores the resulting normalized coordinates in the given slice.

  • User coordinate tags that don’t match an axis are ignored.
  • User coordinate values are clamped to the range of their associated axis before normalization.
  • If more than one user coordinate is provided for the same tag, the last one is used.
  • If no user coordinate for an axis is provided, the associated coordinate is set to the normalized value 0.0, representing the default location in variation space.
  • The length of normalized_coords should equal the number of axes present in the this table. If the length is smaller, axes at out of bounds indices are ignored. If the length is larger, the excess entries will be filled with zeros.

If the Avar table is provided, applies remapping of coordinates according to the specification.